@@ -28,7 +28,7 @@
 (defvar mew-addrbook-orig-alist nil
   "(key (addr1, addr2) nickname name) or (key addr)")
 
-(defsubst mew-adbkorigent-by-shortname (user)
+(defun mew-adbkorigent-by-shortname (user)
   (mew-addrbook-alias-hit user mew-addrbook-orig-alist))
 
 ;;
@@ -36,29 +36,29 @@
 (defvar mew-addrbook-alist nil ;; mew-alias-auto-alist is appended
   "(key addr) or (key (addr1, addr2) nickname name)")
 
-(defsubst mew-adbkent-by-addr-with-alist (addr alist)
+(defun mew-adbkent-by-addr-with-alist (addr alist)
   (mew-assoc-member-case-equal addr alist 1))
 
-(defsubst mew-adbkent-by-addr (addr)
+(defun mew-adbkent-by-addr (addr)
   (mew-adbkent-by-addr-with-alist addr mew-addrbook-alist))
 
-(defsubst mew-adbkent-by-addr2 (addr)
+(defun mew-adbkent-by-addr2 (addr)
   ;; for nickname and name, mew-addrbook-orig-alist is enough and fast
   (mew-adbkent-by-addr-with-alist addr mew-addrbook-orig-alist))
 
-(defsubst mew-adbkent-shortname (adbkent)
+(defun mew-adbkent-shortname (adbkent)
   (nth 0 adbkent))
 
-(defsubst mew-adbkent-addrs (adbkent)
+(defun mew-adbkent-addrs (adbkent)
   (nth 1 adbkent))
 
-(defsubst mew-adbkent-nickname (adbkent)
+(defun mew-adbkent-nickname (adbkent)
   (nth 2 adbkent))
 
-(defsubst mew-adbkent-name (adbkent)
+(defun mew-adbkent-name (adbkent)
   (nth 3 adbkent))
 
-(defsubst mew-addrbook-shortname-get (addr)
+(defun mew-addrbook-shortname-get (addr)
   (mew-adbkent-shortname (mew-adbkent-by-addr addr)))
 
 (defun mew-addrbook-addrs-get (addr)
@@ -78,13 +78,13 @@
 (defvar mew-alias-auto-alist nil
   "(key addr)")
 
-(defsubst mew-autoent-by-shortname (user)
+(defun mew-autoent-by-shortname (user)
   (assoc user mew-alias-auto-alist))
 
-(defsubst mew-autoent-shortname (autoent)
+(defun mew-autoent-shortname (autoent)
   (nth 0 autoent))
 
-(defsubst mew-autoent-addr (autoent)
+(defun mew-autoent-addr (autoent)
   (nth 1 autoent))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
@@ -93,21 +93,11 @@
 ;;;
 
 (defun mew-alias-short-to-full (alist)
-  (let (ret)
-    (while alist
-      (setq ret (cons (cdr (car alist)) ret))
-      (setq alist (cdr alist)))
-    (nreverse ret)))
+  (mapcar (lambda (x) (cdr x)) alist))
 
 ;; duplicated?
 (defun mew-alias-full-to-short (alist)
-  (let (ret ent user)
-    (while alist
-      (setq ent (car alist))
-      (setq alist (cdr alist))
-      (setq user (downcase (mew-addrstr-extract-user (car ent))))
-      (setq ret (cons (cons user ent) ret)))
-    (nreverse ret)))
+  (mapcar (lambda (x) (cons (downcase (mew-addrstr-extract-user x)) x)) alist))
 
 (defun mew-addrbook-setup ()
   (if (and mew-alias-auto-file (null mew-alias-auto-alist))
@@ -155,14 +145,11 @@
       ret)))
 
 (defun mew-alias-expand-addrs (key alist count)
-  (let ((keys (mew-split key ?,))
+  (let ((keys (delete "" (mapcar 'mew-chop (mew-split key ?,))))
 	ret)
-    (setq keys (mapcar 'mew-chop keys))
-    (setq keys (delete "" keys))
-    (while keys
-      (setq ret (nconc ret (mew-alias-expand (car keys) alist count)))
-      (setq keys (cdr keys)))
-    ret))
+   (dolist (key keys)
+     (setq ret (nconc ret (mew-alias-expand key alist count))))
+   ret))
 
 (defun mew-alias-expand (key alist count)
   "Expand KEY to a list of addresses according to ALIST.
@@ -265,9 +252,8 @@ returned."
 	 (files pars) ;; included
 	 par chr path beg end qchar ret)
     ;; include parents files
-    (while pars
-      (setq par (expand-file-name (car pars) mew-conf-path))
-      (setq pars (cdr pars))
+    (dolist (ent pars)
+      (setq par (expand-file-name ent mew-conf-path))
       (when (file-readable-p par)
 	(setq ret t)
 	(mew-insert-file-contents par)
@@ -341,7 +327,7 @@ returned."
       (when (mew-addrbook-insert-file
 	     mew-addrbook-file mew-addrbook-comment-regex 'unquote)
 	(goto-char (point-min))
-	(while (re-search-forward "^ ?\\([^ \n:]+\\) ?\\(:?\\) ?\\([^ \n]+\\)" nil t)
+	(while (re-search-forward "^ ?\\([^ \n:]+\\) ?\\(:?\\) ?\\([^ \t\n]+\\)" nil t)
 	  (setq alias (mew-addrbook-strsafe (mew-match-string 1)))
 	  (setq colon (mew-match-string 2))
 	  (setq addrs (mew-addrbook-strsafe (mew-match-string 3)))
@@ -428,13 +414,9 @@ it will add an alias."
      (insert "\n"))))
 
 (defun mew-addrbook-mode (mname)
-  "\\<mew-addrbook-mode-map>
-Mew Addrbook mode:: major mode to register Addrbook.
-The keys that are defined for this mode are:
+  "A major mode to register Addrbook.
 
-\\[mew-addrbook-register]	Register information in Addrbook mode to Addrbook.
-\\[mew-addrbook-kill]	Kill Addrbook mode.
-"
+\\{mew-addrbook-mode-map}"
   (interactive)
   (setq major-mode 'mew-addrbook-mode)
   (setq mode-name mname)
@@ -563,13 +545,13 @@ reflected."
 
 ;;; Copyright Notice:
 
-;; Copyright (C) 1999-2005 Mew developing team.
+;; Copyright (C) 1999-2009 Mew developing team.
 ;; All rights reserved.
 
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -578,7 +560,7 @@ reflected."
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS'' AND
 ;; ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 ;; IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
